@@ -831,10 +831,10 @@ PyObject *pystr_axis = NULL;
 #line 393
 static int
 intern_strings(void) {
-    pystr_a = PyString_InternFromString("a");
-    pystr_n = PyString_InternFromString("n");
-    pystr_kth = PyString_InternFromString("kth");
-    pystr_axis = PyString_InternFromString("axis");
+    pystr_a = PyUnicode_InternFromString("a");
+    pystr_n = PyUnicode_InternFromString("n");
+    pystr_kth = PyUnicode_InternFromString("kth");
+    pystr_axis = PyUnicode_InternFromString("axis");
     return pystr_a && pystr_n && pystr_axis;
 }
 
@@ -1442,7 +1442,6 @@ nra_methods[] = {
 };
 
 #line 1015
-#if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef
 nra_def = {
    PyModuleDef_HEAD_INIT,
@@ -1451,27 +1450,21 @@ nra_def = {
    -1,
    nra_methods
 };
-#endif
 
-#line 1027
+#line 1025
 PyMODINIT_FUNC
-#if PY_MAJOR_VERSION >= 3
-#define RETVAL m
 PyInit_nonreduce_axis(void)
-#else
-#define RETVAL
-initnonreduce_axis(void)
-#endif
 {
-    #if PY_MAJOR_VERSION >=3
-        PyObject *m = PyModule_Create(&nra_def);
-    #else
-        PyObject *m = Py_InitModule3("nonreduce_axis", nra_methods, nra_doc);
+    PyObject *m = PyModule_Create(&nra_def);
+    if (m == NULL) return NULL;
+
+    #ifdef Py_GIL_DISABLED
+        PyUnstable_Module_SetGIL(m, Py_MOD_GIL_NOT_USED);
     #endif
-    if (m == NULL) return RETVAL;
+
     import_array();
     if (!intern_strings()) {
-        return RETVAL;
+        return NULL;
     }
-    return RETVAL;
+    return m;
 }
