@@ -2666,9 +2666,9 @@ PyObject *pystr_ddof = NULL;
 #line 1060
 static int
 intern_strings(void) {
-    pystr_a = PyString_InternFromString("a");
-    pystr_axis = PyString_InternFromString("axis");
-    pystr_ddof = PyString_InternFromString("ddof");
+    pystr_a = PyUnicode_InternFromString("a");
+    pystr_axis = PyUnicode_InternFromString("axis");
+    pystr_ddof = PyUnicode_InternFromString("ddof");
     return pystr_a && pystr_axis && pystr_ddof;
 }
 
@@ -3533,7 +3533,6 @@ reduce_methods[] = {
 };
 
 #line 1954
-#if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef
 reduce_def = {
    PyModuleDef_HEAD_INIT,
@@ -3542,27 +3541,21 @@ reduce_def = {
    -1,
    reduce_methods
 };
-#endif
 
-#line 1966
+#line 1964
 PyMODINIT_FUNC
-#if PY_MAJOR_VERSION >= 3
-#define RETVAL m
 PyInit_reduce(void)
-#else
-#define RETVAL
-initreduce(void)
-#endif
 {
-    #if PY_MAJOR_VERSION >=3
-        PyObject *m = PyModule_Create(&reduce_def);
-    #else
-        PyObject *m = Py_InitModule3("reduce", reduce_methods, reduce_doc);
+    PyObject *m = PyModule_Create(&reduce_def);
+    if (m == NULL) return NULL;
+
+    #ifdef Py_GIL_DISABLED
+        PyUnstable_Module_SetGIL(m, Py_MOD_GIL_NOT_USED);
     #endif
-    if (m == NULL) return RETVAL;
+
     import_array();
     if (!intern_strings()) {
-        return RETVAL;
+        return NULL;
     }
-    return RETVAL;
+    return m;
 }
